/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: NamingContextFactory.java 7:12:37 PM ddesjardins $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.communication.jndi.tribe.connection;

import java.util.Hashtable;

import javax.naming.Context;
import javax.naming.NamingException;
import javax.naming.spi.InitialContextFactory;

/**
 * This class is the InitialContextFactory implementation, it will create the
 * InitialContext
 *
 * @author ddesjardins - eBMWebsourcing
 */
public class NamingContextFactory implements InitialContextFactory {

    public static final int DEFAULT_JNDI_PORT = 7720;

    /**
     * @see InitialContextFactory#getInitialContext(Hashtable)
     */
    @SuppressWarnings("unchecked")
    public Context getInitialContext(Hashtable<?, ?> environment)
        throws NamingException {
        // Default settings
        String host = (String) environment.get("java.naming.factory.host");
        String portStr = (String) environment.get("java.naming.factory.port");

        if (host == null) {
            throw new NamingException(
                "You must specify the property java.naming.factory.host in the environment");
        }
        if (portStr == null) {
            throw new NamingException(
                "You must specify the property java.naming.factory.port in the environment");
        }

        int port = DEFAULT_JNDI_PORT;
        try {
            port = Integer.parseInt(portStr);
        } catch (NumberFormatException e) {
        }

        NamingConnection jndiConnection = new JNDIConnection(port, host);
        NamingContextImpl namingContextImpl = new NamingContextImpl(
            (Hashtable<String, Object>) environment, jndiConnection, "/");

        return namingContextImpl;
    }
}
