/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.jbi.management.task;

import java.io.File;
import java.io.IOException;
import java.net.URI;
import java.util.HashMap;

import org.apache.commons.io.FileUtils;
import org.objectweb.petals.util.LoggingUtil;

/**
 * This task copies archive file to <i>installed</i> dir <br/>
 * Inputs : archive {@link URI} <br/>
 * 
 * @author ofabre - EBM Websourcing
 * 
 */
public class CopyArchiveToInstalledDirTask extends AbstractFileManipulationTask {

    /**
     * logger wrapper
     */
    protected LoggingUtil log;

    public CopyArchiveToInstalledDirTask(LoggingUtil log) {
        super();
        this.log = log;
    }

    public void execute(HashMap context) throws Exception {
        URI archiveURI = (URI) context
                .get(TaskContextConstants.ARCHIVE_URI);

        File file = getArchiveFile(archiveURI);
        File installedArchive = getInstalledArchive(file);

        FileUtils.copyFile(file, installedArchive);

    }

    public void undo(HashMap context) {
        URI archiveURI = (URI) context
                .get(TaskContextConstants.ARCHIVE_URI);

        File file = getArchiveFile(archiveURI);
        File installedArchive = getInstalledArchive(file);

        try {
            FileUtils.forceDelete(installedArchive);
        } catch (IOException e) {
            String msg = "Failed to revert a CopyArchiveToInstalledDirTask";
            log.error(msg, e);
        }

    }

}
