/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.jbi.management.task.installation;

import java.io.File;
import java.util.List;

import org.objectweb.petals.PetalsException;
import org.objectweb.petals.util.StringHelper;
import org.ow2.petals.jbi.descriptor.JBIDescriptor;
import org.objectweb.petals.jbi.management.autoload.AutoLoaderServiceImpl;


/**
 * 
 * @author ofabre
 * 
 */
public class InstallationUtils {

    /**
     * Check the classpath element of the jbi descriptor
     * 
     * @param filePackage
     *            the entity package root
     * @param classPath
     *            a List of classpath elements to check
     * @throws PetalsException
     *             if one of the classpath elements is null, empty or or missing
     */
    public static void checkClassPathElements(File filePackage,
        List<String> classPath) throws PetalsException {
        String msg;

        for (String pathElement : classPath) {

            /*
             * empty class-path elements is not allowed
             */
            if (StringHelper.isNullOrEmpty(pathElement)) {
                msg = "An empty class-path element found "
                    + "in the JBI Descriptor file (jbi.xml).";
                throw new PetalsException(msg);
            }

            /*
             * check if the specified path element exists within archive
             */
            if (!".".equals(pathElement) && !hasEntry(filePackage, pathElement)) {
                msg = "The class-path element '" + pathElement
                    + "' declared in "
                    + "JBI Descriptor not found within installation "
                    + "package Zip archive file.";
                throw new PetalsException(msg);
            }
        }
    }

    private static boolean hasEntry(File filePackage, String pathElement) {
        File artifactFile = new File(filePackage, pathElement);
        return artifactFile.exists();
    }

    /**
     * Return the name of the component description found in the descriptor
     * 
     * @param descriptor
     *            the JBI descriptor, must have been validated and checked
     *            before
     * @return the name of the component
     */
    public static String getComponentNameFromDescriptor(JBIDescriptor descriptor) {
        return descriptor.getComponent().getIdentification().getName();
    }

    /**
     * Return the name of the shared lib description found in the descriptor
     * 
     * @param descriptor
     *            the JBI descriptor, must have been validated and checked
     *            before
     * @return the name of the shared lib
     */
    public static String getSLNameFromDescriptor(JBIDescriptor descriptor) {
        return descriptor.getSharedLibrary().getIdentification().getName();
    }

    /**
     * Get a file with the given File name in the "uninstalled directory"
     * 
     * @param file
     *            the file to look for, must be non null
     * @return a File pointing on the File name in the "uninstalled directory"
     * @throws NullPointerException
     *             if the given file is null
     */
    public static File getUninstalledArchive(File file) {
        return new File(AutoLoaderServiceImpl.getUninstalledDirectory(), file
            .getName());
    }

}
